==> gstep-core-0.6.0.tar.gz: gstep-core-0.6.0/base/acconfig.h <==
/* Macros that may be defined by the aclocal.m4 extentions to `configure' 
   for GNUstep Base Library. */

#undef CON_AUTOLOAD

#undef NeXT_cc
#undef NeXT_runtime

#undef VSPRINTF_RETURNS_LENGTH

/* The number of bytes in a int.  */
#undef SIZEOF_INT

/* Define if you have the getcwd function.  */
#undef HAVE_GETCWD

/* Define if you have the inet_aton function.  */
#undef HAVE_INET_ATON

/* Define if you have the killpg function.  */
#undef HAVE_KILLPG

/* Define if you have the setpgrp function.  */
#undef HAVE_SETPGRP

/* Define if you have the setpgid function.  */
#undef HAVE_SETPGID

/* Define if you have the mmap function.  */
#undef HAVE_MMAP

/* Define if you have the register_printf_function function.  */
#undef HAVE_REGISTER_PRINTF_FUNCTION

/* Define if you have the shmctl function.  */
#undef HAVE_SHMCTL

/* Define if you have the mkstemp function.  */
#undef HAVE_MKSTEMP

/* Define if you have the statvfs function.  */
#undef HAVE_STATVFS

/* Define if you have the strerror function.  */
#undef HAVE_STRERROR

/* Define if you have the times function.  */
#undef HAVE_TIMES

/* Define if you have the usleep function.  */
#undef HAVE_USLEEP

/* Define if you have the valloc function.  */
#undef HAVE_VALLOC

/* Define if you have the vsprintf function.  */
#undef HAVE_VSPRINTF

/* Define if you have the <dirent.h> header file.  */
#undef HAVE_DIRENT_H

/* Define if you have the <memory.h> header file.  */
#undef HAVE_MEMORY_H

/* Define if you have the <ndir.h> header file.  */
#undef HAVE_NDIR_H

/* Define if you have the <netinet/in.h> header file.  */
#undef HAVE_NETINET_IN_H

/* Define if you have the <pwd.h> header file.  */
#undef HAVE_PWD_H

/* Define if you have the <getgrent.h> header file.  */
#undef HAVE_GRP_H

/* Define if you have the <string.h> header file.  */
#undef HAVE_STRING_H

/* Define if you have the <syslog.h> header file.  */
#undef HAVE_SYSLOG_H
#undef HAVE_SYSLOG

/* Define if you have the <sys/dir.h> header file.  */
#undef HAVE_SYS_DIR_H

/* Define if you have the <sys/ndir.h> header file.  */
#undef HAVE_SYS_NDIR_H

/* Define if you have the <sys/resource.h> header file.  */
#undef HAVE_SYS_RESOURCE_H

/* Define if you have the <sys/rusage.h> header file.  */
#undef HAVE_SYS_RUSAGE_H

/* Define if you have the <sys/socket.h> header file.  */
#undef HAVE_SYS_SOCKET_H

/* Define if you have the <sys/stat.h> header file.  */
#undef HAVE_SYS_STAT_H

/* Define if you have the <sys/statfs.h> header file.  */
#undef HAVE_SYS_STATFS_H

/* Define if you have the <sys/statvfs.h> header file.  */
#undef HAVE_SYS_STATVFS_H

/* Define if you have the <sys/time.h> header file.  */
#undef HAVE_SYS_TIME_H

/* Define if you have the <sys/vfs.h> header file.  */
#undef HAVE_SYS_VFS_H

/* Define if you have the <ucbinclude/sys/resource.h> header file.  */
#undef HAVE_UCBINCLUDE_SYS_RESOURCE_H

/* Define if you have the <values.h> header file.  */
#undef HAVE_VALUES_H

/* Define if your kernel supports the /proc filesystem */
#undef HAVE_PROC_FS

/* Define if your Obj-C compiler calls +load methods before main */
#undef HAVE_LOAD_METHOD 

/* Define if your Lib C defines program_invocation_name */
#undef HAVE_PROGRAM_INVOCATION_NAME

==> gstep-core-0.6.6.tar.gz: gstep-core-0.6.6/base/acconfig.h <==
/* Macros that may be defined by the aclocal.m4 extentions to `configure' 
   for GNUstep Base Library. */

#undef CON_AUTOLOAD

#undef NeXT_cc
#undef NeXT_runtime

#undef VSPRINTF_RETURNS_LENGTH
#undef VASPRINTF_RETURNS_LENGTH

/* Define if your system needs to have short/int word aligned */
#undef NEED_WORD_ALIGNMENT

/* The number of bytes in a int.  */
#undef SIZEOF_INT

/* Define if you have the getcwd function.  */
#undef HAVE_GETCWD

/* Define if you have the inet_aton function.  */
#undef HAVE_INET_ATON

/* Define if you have the killpg function.  */
#undef HAVE_KILLPG

/* Define if you have the setpgrp function.  */
#undef HAVE_SETPGRP

/* Define if you have the setpgid function.  */
#undef HAVE_SETPGID

/* Define if you have the mmap function.  */
#undef HAVE_MMAP

/* Define if you have the register_printf_function function.  */
#undef HAVE_REGISTER_PRINTF_FUNCTION

/* Define if you have the shmctl function.  */
#undef HAVE_SHMCTL

/* Define if you have the mkstemp function.  */
#undef HAVE_MKSTEMP

/* Define if you have the statvfs function.  */
#undef HAVE_STATVFS

/* Define if you have the strerror function.  */
#undef HAVE_STRERROR

/* Define if you have the times function.  */
#undef HAVE_TIMES

/* Define if you have the usleep function.  */
#undef HAVE_USLEEP

/* Define if you have the valloc function.  */
#undef HAVE_VALLOC

/* Define if you have the vsprintf function.  */
#undef HAVE_VSPRINTF

/* Define if you have the <dirent.h> header file.  */
#undef HAVE_DIRENT_H

/* Define if you have the <memory.h> header file.  */
#undef HAVE_MEMORY_H

/* Define if you have the <ndir.h> header file.  */
#undef HAVE_NDIR_H

/* Define if you have the <netinet/in.h> header file.  */
#undef HAVE_NETINET_IN_H

/* Define if you have the <pwd.h> header file.  */
#undef HAVE_PWD_H

/* Define if you have the <getgrent.h> header file.  */
#undef HAVE_GRP_H

/* Define if you have the <string.h> header file.  */
#undef HAVE_STRING_H

/* Define if you have the <syslog.h> header file.  */
#undef HAVE_SYSLOG_H
#undef HAVE_SYSLOG

/* Define if you have the <sys/dir.h> header file.  */
#undef HAVE_SYS_DIR_H

/* Define if you have the <sys/ndir.h> header file.  */
#undef HAVE_SYS_NDIR_H

/* Define if you have the <sys/resource.h> header file.  */
#undef HAVE_SYS_RESOURCE_H

/* Define if you have the <sys/rusage.h> header file.  */
#undef HAVE_SYS_RUSAGE_H

/* Define if you have the <sys/socket.h> header file.  */
#undef HAVE_SYS_SOCKET_H

/* Define if you have the <sys/stat.h> header file.  */
#undef HAVE_SYS_STAT_H

/* Define if you have the <sys/statfs.h> header file.  */
#undef HAVE_SYS_STATFS_H

/* Define if you have the <sys/statvfs.h> header file.  */
#undef HAVE_SYS_STATVFS_H

/* Define if you have the <sys/time.h> header file.  */
#undef HAVE_SYS_TIME_H

/* Define if you have the <sys/vfs.h> header file.  */
#undef HAVE_SYS_VFS_H

/* Define if you have the <ucbinclude/sys/resource.h> header file.  */
#undef HAVE_UCBINCLUDE_SYS_RESOURCE_H

/* Define if you have the <values.h> header file.  */
#undef HAVE_VALUES_H

/* Define if your kernel supports the /proc filesystem */
#undef HAVE_PROC_FS

/* Define if your Obj-C compiler calls +load methods before main */
#undef HAVE_LOAD_METHOD 

/* Define if objc-api.h defines this function */
#undef HAVE_OBJC_GET_UNINSTALLED_DTABLE

/* Define if your Lib C defines program_invocation_name */
#undef HAVE_PROGRAM_INVOCATION_NAME

/* Define if your system has a /proc/self/exe symlink to the executable */
#undef HAVE_PROC_FS_EXE_LINK
